# THIS FILE IS GENERATED FROM setup.py in pagosonline
short_version = '0.5.2'
version = '0.5.2'
full_version = '0.5.2'
git_revision = '5477aee418dffc32049fc8eaf263b9f954a48801'
release = True

if not release:
    version = full_version
